@@ -222,30 +222,30 @@ class songs(api_base):
             data = data.annotate(VoteCount=Count("User"))
             data = data.annotate(MinCreated=Min("Created"))
             data = data.order_by("-VoteCount", "MinCreated")[0:1].get()
+            self.addToHistory(data.Song, data.User)
             song_instance = data.Song
-            user_list = data.User
             data.delete()
         except ObjectDoesNotExist:
             song_instance = Song.objects.order_by('?')[0:1].get()
-            user_list = None
+            self.addToHistory(song_instance, None)
 
         # remove missing files
         if not os.path.exists(song_instance.Filename):
             Song.objects.all().filter(id=song_instance.id).delete()
             return self.getNextSong()
 
-        # store in history
+        return song_instance
+
+    def addToHistory(self, song_instance, user_list):
         history_instance = History(
             Song=song_instance
         )
         history_instance.save()
-        if None != user_list and user_list.count() > 0:
+
+        if user_list is not None and user_list.count() > 0:
             for user_instance in user_list.all():
                 history_instance.User.add(user_instance)
 
-        return song_instance
-
-
 class history(api_base):
     order_by_fields = {
         "title": "Song__Title",
@@ -259,7 +259,9 @@ class history(api_base):
     def index(self, page=1):
         object_list = History.objects.all()
         object_list = self.source_set_order(object_list)
+        return self.build_result(object_list, page)
 
+    def build_result(self, object_list, page):
         # prepare result
         result = self.get_default_result("history", page)
 
@@ -312,7 +314,7 @@ class history(api_base):
 
             if not item.User.count() == 0:
                 for user in item.User.all():
-                    result["users"].append({
+                    dataset["users"].append({
                         "id": user.id,
                         "name": user.username
                     })
@@ -323,6 +325,24 @@ class history(api_base):
         return result
 
 
+class history_my(history):
+    order_by_fields = {
+        "title": "Song__Title",
+        "artist": "Song__Artist__Name",
+        "album": "Song__Album__Title",
+        "year": "Song__Year",
+        "genre": "Song__Genre__Name",
+        "created": "Created",
+    }
+
+    def index(self, page=1):
+        object_list = History.objects.all().filter(User__id=self.user_id)
+        object_list = self.source_set_order(object_list)
+        result = self.build_result(object_list, page)
+        result["type"] = "history/my"
+        return result
+
+
 class queue(api_base):
     order_by_fields = {
         "title": "Song__Title",
@@ -472,7 +492,7 @@ class favourites(api_base):
 
     def get(self, song_id):
         song = Song.objects.get(id=song_id)
-        item = Favourite.objects.get(Song=song)
+        item = Favourite.objects.get(Song=song,User__id=self.user_id)
 
         result = {
             "id": item.Song.id,
